==> windmill_api-1.527.0.tar.gz: windmill_api-1.527.0/windmill_api/models/get_flow_version_response_200_value_failure_module_retry.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_flow_version_response_200_value_failure_module_retry_constant import (
        GetFlowVersionResponse200ValueFailureModuleRetryConstant,
    )
    from ..models.get_flow_version_response_200_value_failure_module_retry_exponential import (
        GetFlowVersionResponse200ValueFailureModuleRetryExponential,
    )


T = TypeVar("T", bound="GetFlowVersionResponse200ValueFailureModuleRetry")


@_attrs_define
class GetFlowVersionResponse200ValueFailureModuleRetry:
    """
    Attributes:
        constant (Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryConstant]):
        exponential (Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryExponential]):
    """

    constant: Union[Unset, "GetFlowVersionResponse200ValueFailureModuleRetryConstant"] = UNSET
    exponential: Union[Unset, "GetFlowVersionResponse200ValueFailureModuleRetryExponential"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        constant: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.constant, Unset):
            constant = self.constant.to_dict()

        exponential: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exponential, Unset):
            exponential = self.exponential.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if constant is not UNSET:
            field_dict["constant"] = constant
        if exponential is not UNSET:
            field_dict["exponential"] = exponential

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.get_flow_version_response_200_value_failure_module_retry_constant import (
            GetFlowVersionResponse200ValueFailureModuleRetryConstant,
        )
        from ..models.get_flow_version_response_200_value_failure_module_retry_exponential import (
            GetFlowVersionResponse200ValueFailureModuleRetryExponential,
        )

        d = src_dict.copy()
        _constant = d.pop("constant", UNSET)
        constant: Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryConstant]
        if isinstance(_constant, Unset):
            constant = UNSET
        else:
            constant = GetFlowVersionResponse200ValueFailureModuleRetryConstant.from_dict(_constant)

        _exponential = d.pop("exponential", UNSET)
        exponential: Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryExponential]
        if isinstance(_exponential, Unset):
            exponential = UNSET
        else:
            exponential = GetFlowVersionResponse200ValueFailureModuleRetryExponential.from_dict(_exponential)

        get_flow_version_response_200_value_failure_module_retry = cls(
            constant=constant,
            exponential=exponential,
        )

        get_flow_version_response_200_value_failure_module_retry.additional_properties = d
        return get_flow_version_response_200_value_failure_module_retry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.583.0.tar.gz: windmill_api-1.583.0/windmill_api/models/get_flow_version_response_200_value_failure_module_retry.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_flow_version_response_200_value_failure_module_retry_constant import (
        GetFlowVersionResponse200ValueFailureModuleRetryConstant,
    )
    from ..models.get_flow_version_response_200_value_failure_module_retry_exponential import (
        GetFlowVersionResponse200ValueFailureModuleRetryExponential,
    )
    from ..models.get_flow_version_response_200_value_failure_module_retry_retry_if import (
        GetFlowVersionResponse200ValueFailureModuleRetryRetryIf,
    )


T = TypeVar("T", bound="GetFlowVersionResponse200ValueFailureModuleRetry")


@_attrs_define
class GetFlowVersionResponse200ValueFailureModuleRetry:
    """
    Attributes:
        constant (Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryConstant]):
        exponential (Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryExponential]):
        retry_if (Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryRetryIf]):
    """

    constant: Union[Unset, "GetFlowVersionResponse200ValueFailureModuleRetryConstant"] = UNSET
    exponential: Union[Unset, "GetFlowVersionResponse200ValueFailureModuleRetryExponential"] = UNSET
    retry_if: Union[Unset, "GetFlowVersionResponse200ValueFailureModuleRetryRetryIf"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        constant: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.constant, Unset):
            constant = self.constant.to_dict()

        exponential: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exponential, Unset):
            exponential = self.exponential.to_dict()

        retry_if: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.retry_if, Unset):
            retry_if = self.retry_if.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if constant is not UNSET:
            field_dict["constant"] = constant
        if exponential is not UNSET:
            field_dict["exponential"] = exponential
        if retry_if is not UNSET:
            field_dict["retry_if"] = retry_if

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.get_flow_version_response_200_value_failure_module_retry_constant import (
            GetFlowVersionResponse200ValueFailureModuleRetryConstant,
        )
        from ..models.get_flow_version_response_200_value_failure_module_retry_exponential import (
            GetFlowVersionResponse200ValueFailureModuleRetryExponential,
        )
        from ..models.get_flow_version_response_200_value_failure_module_retry_retry_if import (
            GetFlowVersionResponse200ValueFailureModuleRetryRetryIf,
        )

        d = src_dict.copy()
        _constant = d.pop("constant", UNSET)
        constant: Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryConstant]
        if isinstance(_constant, Unset):
            constant = UNSET
        else:
            constant = GetFlowVersionResponse200ValueFailureModuleRetryConstant.from_dict(_constant)

        _exponential = d.pop("exponential", UNSET)
        exponential: Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryExponential]
        if isinstance(_exponential, Unset):
            exponential = UNSET
        else:
            exponential = GetFlowVersionResponse200ValueFailureModuleRetryExponential.from_dict(_exponential)

        _retry_if = d.pop("retry_if", UNSET)
        retry_if: Union[Unset, GetFlowVersionResponse200ValueFailureModuleRetryRetryIf]
        if isinstance(_retry_if, Unset):
            retry_if = UNSET
        else:
            retry_if = GetFlowVersionResponse200ValueFailureModuleRetryRetryIf.from_dict(_retry_if)

        get_flow_version_response_200_value_failure_module_retry = cls(
            constant=constant,
            exponential=exponential,
            retry_if=retry_if,
        )

        get_flow_version_response_200_value_failure_module_retry.additional_properties = d
        return get_flow_version_response_200_value_failure_module_retry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
